﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using CSCreateLowIntegrityProcess;
using NDesk.Options;

namespace clriecache
{
    class Program
    {
        static void ShowHelp(string Message, OptionSet OptionSet)
        {
            if (!String.IsNullOrEmpty(Message))
                Console.WriteLine(Message + Environment.NewLine);

            Console.WriteLine("Usage: " + Environment.NewLine
                + System.AppDomain.CurrentDomain.FriendlyName
                + " [-h] [-c] [-v] [-rv] [-cv]");

            Console.WriteLine();
            Console.WriteLine("Arguments:");
            OptionSet.WriteOptionDescriptions(Console.Out);

            Console.WriteLine(Environment.NewLine
                + "This program contains following components:" + Environment.NewLine
                + "NDesk.Options parser: http://ndesk.org/Options");

        }

        static void Main(string[] args)
        {
            try
            {
                bool showHelp = false;
                bool deleteCookies = false;
                bool verbose = false;
                bool readOnly = false;

                var options = new OptionSet()
                {
                    {"?|h|help", "Show this help.", o => showHelp = o != null},
                    {"c|cookies", "Delete cookies.", o => deleteCookies = o != null},
                    {"v|verbose", "Show cache content.", o => verbose = o != null},
                    {"r|readonly", "Don't delete cache content.", o => readOnly = o != null}
                };

                options.Parse(args);

                if (!showHelp)
                {
                    ClearIECache ieCache = new ClearIECache();
                    ieCache.ClearCache(deleteCookies, verbose, readOnly);

                    int osVersion = Environment.OSVersion.Version.Major;
                    if (osVersion >= 6)
                    {
                        RunLow rl = new RunLow();
                        string executable = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, AppDomain.CurrentDomain.FriendlyName);
                        int integrityLevel = rl.GetProcessIntegrityLevel();

                        if (integrityLevel == NativeMethod.SECURITY_MANDATORY_MEDIUM_RID)
                            rl.StartLowProcess(executable, args);
                    }
                }
                else
                {
                    ShowHelp(null, options);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.StackTrace);
                Console.WriteLine();
                Console.WriteLine(e.Message);
            }
        }
    }
}
